import { OrganizationType } from "../../../type/organization-type";
import { AbstractVersionableTO } from "./versionable";
/**
 * Interface used to define an organization. You may want to use AbstractOrganizationTO which has more field
 */
export interface ItfOrganization {
    parentOrganizationId: number;
    organizationId: number;
    name: string;
}
/**
 * Interace used only to define which organization type can be a parent of a group (customer, site, group)
 */
export interface ItfOrganizationCustomerGroupParent extends ItfOrganization {
}
export declare class AbstractOrganizationTO extends AbstractVersionableTO implements ItfOrganization {
    constructor(type: OrganizationType, name?: string, organizationId?: number);
    parentOrganizationId: number;
    organizationId: number;
    type: OrganizationType;
    name: string;
    location: string;
    phone: string;
}
export declare class OrganizationHostingProviderTO extends AbstractOrganizationTO {
    constructor(name?: string, organizationId?: number);
}
export declare class OrganizationVspTO extends AbstractOrganizationTO {
    constructor(name?: string, organizationId?: number);
    emailNotification: string;
    emailBusiness: string;
    emailTechnical: string;
    listSecurityCenterSystem: Array<number>;
    listCapabilities: Array<number>;
}
export declare class OrganizationCustomerTO extends AbstractOrganizationTO implements ItfOrganizationCustomerGroupParent {
    constructor(name?: string, organizationId?: number);
    emailBusiness: string;
    emailTechnical: string;
    reference: string;
    allowsVspToViewImages: boolean;
    allEventsEnabled: boolean;
}
export declare class OrganizationCustomerSiteTO extends AbstractOrganizationTO implements ItfOrganizationCustomerGroupParent {
    constructor(name?: string, organizationId?: number);
    timezone: string;
    reference: string;
    address: string;
    city: string;
    coordinate: string;
    alarmCenterNotificationEnabled: boolean;
    alarmCenterId: number;
    clientId: string;
    biEnabled: boolean;
}
export declare class OrganizationCustomerGroupTO extends AbstractOrganizationTO implements ItfOrganizationCustomerGroupParent {
    constructor(name?: string, organizationId?: number);
}
export declare class OrganizationTreeTO {
    organizationId: number;
    name: string;
    type: OrganizationType;
    children: OrganizationTreeTO[];
}
