

import {OrganizationType} from "../../../type/organization-type";
import {AbstractVersionableTO} from "./versionable";


/**
 * Interface used to define an organization. You may want to use AbstractOrganizationTO which has more field
 */
export interface ItfOrganization{
	parentOrganizationId: number;
	organizationId:number;
	name:string;
}

/**
 * Interace used only to define which organization type can be a parent of a group (customer, site, group)
 */
export interface ItfOrganizationCustomerGroupParent extends ItfOrganization{

}

export class AbstractOrganizationTO extends AbstractVersionableTO implements ItfOrganization{
	public constructor(type: OrganizationType, name?: string, organizationId?: number) {
		super();
		this.name = name;
		this.organizationId = organizationId;
		this.type = type;
	}

	public parentOrganizationId: number;
	public organizationId: number;
	public type: OrganizationType;
	public name: string;
	public location: string;
	public phone: string;
}

export class OrganizationHostingProviderTO extends AbstractOrganizationTO {
	constructor(name?: string, organizationId?: number) {
		super(OrganizationType.HOSTING_PROVIDER, name, organizationId);
	}
}

export class OrganizationVspTO extends AbstractOrganizationTO {
	constructor(name?: string, organizationId?: number) {
		super(OrganizationType.VSP, name, organizationId);
	}

	public emailNotification: string;
	public emailBusiness: string;
	public emailTechnical: string;

	public listSecurityCenterSystem: Array<number>;
	public listCapabilities: Array<number>;
}

export class OrganizationCustomerTO extends AbstractOrganizationTO implements ItfOrganizationCustomerGroupParent{
	constructor(name?: string, organizationId?: number) {
		super(OrganizationType.CUSTOMER, name, organizationId);
	}

	public emailBusiness: string;
	public emailTechnical: string;
	public reference: string;
	public allowsVspToViewImages: boolean;
	public allEventsEnabled: boolean;
}

export class OrganizationCustomerSiteTO extends AbstractOrganizationTO implements ItfOrganizationCustomerGroupParent {

	constructor(name?: string, organizationId?: number) {
		super(OrganizationType.CUSTOMER_SITE, name, organizationId);
	}

	public timezone: string;
	public reference: string;
	public address: string;
	public city: string;
	public coordinate: string;

	public alarmCenterNotificationEnabled: boolean;
	public alarmCenterId: number;
	public clientId: string;

	public biEnabled: boolean;
}

export class OrganizationCustomerGroupTO extends AbstractOrganizationTO implements ItfOrganizationCustomerGroupParent {

	constructor(name?: string, organizationId?: number) {
		super(OrganizationType.CUSTOMER_GROUP, name, organizationId);
	}
}


export class OrganizationTreeTO{
	public organizationId:number;
	public name:string;
	public type:OrganizationType;
	public children:OrganizationTreeTO[];
}